@@ -35,8 +35,6 @@ using namespace std;
 #include "myendian.h"
 #include "pp.h"
 
-using namespace std;
-
 
 const char text_songNumberExceed[] = "WARNING: Selected song number was too high";
 const char text_emptyFile[] = "ERROR: File is empty";
@@ -309,9 +307,9 @@ udword sidTune::loadFile(const char* fileName, ubyte** bufferRef)
     }
     // Open binary input file stream at end of file.
 #if defined(SID_HAVE_IOS_BIN)
-	ifstream myIn( fileName, ios::in|ios::bin );
+	ifstream myIn( fileName, ios::in|ios::bin|ios::ate );
 #else
-	ifstream myIn( fileName, ios::in|ios::binary );
+	ifstream myIn( fileName, ios::in|ios::binary|ios::ate );
 #endif
 	// As a replacement for !is_open(), bad() and the NOT-operator
     // don't seem to work on all systems.
@@ -531,6 +529,8 @@ void sidTune::safeConstructor()
 	cachePtr = 0;
 	cacheLen = 0;
 
+    isSlashedFileName = false;
+
 	fileBuf = ( fileBuf2 = 0 );
 	fileOffset = 0;
 	fileNameExtensions = defaultFileNameExt;
